summaryrefslogtreecommitdiff
path: root/vcl
diff options
context:
space:
mode:
Diffstat (limited to 'vcl')
-rw-r--r--vcl/generic/fontmanager/fontconfig.cxx10
-rw-r--r--vcl/generic/fontmanager/fontmanager.cxx66
-rw-r--r--vcl/generic/glyphs/gcach_ftyp.cxx2
-rw-r--r--vcl/generic/glyphs/gcach_ftyp.hxx6
-rw-r--r--vcl/generic/print/glyphset.hxx6
-rw-r--r--vcl/inc/PhysicalFontCollection.hxx2
-rw-r--r--vcl/inc/cupsmgr.hxx12
-rw-r--r--vcl/inc/fontcache.hxx6
-rw-r--r--vcl/inc/fontmanager.hxx38
-rw-r--r--vcl/inc/generic/glyphcache.hxx9
-rw-r--r--vcl/inc/generic/printergfx.hxx1
-rw-r--r--vcl/inc/headless/svpinst.hxx1
-rw-r--r--vcl/inc/image.h4
-rw-r--r--vcl/inc/impimagetree.hxx9
-rw-r--r--vcl/inc/jobset.h4
-rw-r--r--vcl/inc/opengl/program.hxx4
-rw-r--r--vcl/inc/outdev.h2
-rw-r--r--vcl/inc/outfont.hxx4
-rw-r--r--vcl/inc/print.h4
-rw-r--r--vcl/inc/svdata.hxx4
-rw-r--r--vcl/inc/unx/saldisp.hxx6
-rw-r--r--vcl/inc/unx/salinst.h2
-rw-r--r--vcl/opengl/program.cxx4
-rw-r--r--vcl/source/control/tabctrl.cxx8
-rw-r--r--vcl/source/gdi/configsettings.cxx4
-rw-r--r--vcl/source/gdi/jobset.cxx2
-rw-r--r--vcl/source/gdi/pdfwriter_impl.cxx16
-rw-r--r--vcl/source/gdi/pdfwriter_impl.hxx14
-rw-r--r--vcl/source/gdi/print.cxx8
-rw-r--r--vcl/source/gdi/print3.cxx24
-rw-r--r--vcl/source/helper/canvastools.cxx1
-rw-r--r--vcl/source/outdev/font.cxx2
-rw-r--r--vcl/unx/generic/dtrans/X11_selection.cxx54
-rw-r--r--vcl/unx/generic/dtrans/X11_selection.hxx14
-rw-r--r--vcl/unx/generic/dtrans/X11_service.cxx2
-rw-r--r--vcl/unx/generic/gdi/salgdi3.cxx1
-rw-r--r--vcl/unx/generic/printer/cupsmgr.cxx20
-rw-r--r--vcl/unx/generic/printer/ppdparser.cxx13
-rw-r--r--vcl/unx/generic/printer/printerinfomanager.cxx30
-rw-r--r--vcl/unx/gtk/gdi/salnativewidgets-gtk.cxx4
40 files changed, 210 insertions, 213 deletions
diff --git a/vcl/generic/fontmanager/fontconfig.cxx b/vcl/generic/fontmanager/fontconfig.cxx
index 128193c26889..839a722aeda3 100644
--- a/vcl/generic/fontmanager/fontconfig.cxx
+++ b/vcl/generic/fontmanager/fontconfig.cxx
@@ -85,8 +85,8 @@ public:
FcResult LocalizedElementFromPattern(FcPattern* pPattern, FcChar8 **family,
const char *elementtype, const char *elementlangtype);
//to-do, make private and add some cleanish accessor methods
- boost::unordered_map< OString, OString, OStringHash > m_aFontNameToLocalized;
- boost::unordered_map< OString, OString, OStringHash > m_aLocalizedToCanonical;
+ std::unordered_map< OString, OString, OStringHash > m_aFontNameToLocalized;
+ std::unordered_map< OString, OString, OStringHash > m_aLocalizedToCanonical;
private:
void cacheLocalizedFontNames(const FcChar8 *origfontname, const FcChar8 *bestfontname, const std::vector< lang_and_element > &lang_and_elements);
@@ -472,7 +472,7 @@ static void lcl_FcFontSetRemove(FcFontSet* pFSet, int i)
memmove(pFSet->fonts + i, pFSet->fonts + i + 1, nTail*sizeof(FcPattern*));
}
-void PrintFontManager::countFontconfigFonts( boost::unordered_map<OString, int, OStringHash>& o_rVisitedPaths )
+void PrintFontManager::countFontconfigFonts( std::unordered_map<OString, int, OStringHash>& o_rVisitedPaths )
{
#if OSL_DEBUG_LEVEL > 1
int nFonts = 0;
@@ -1052,7 +1052,7 @@ bool PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
if( eFamilyRes == FcResultMatch )
{
OString sFamily((sal_Char*)family);
- boost::unordered_map< OString, OString, OStringHash >::const_iterator aI =
+ std::unordered_map< OString, OString, OStringHash >::const_iterator aI =
rWrapper.m_aFontNameToLocalized.find(sFamily);
if (aI != rWrapper.m_aFontNameToLocalized.end())
sFamily = aI->second;
@@ -1181,7 +1181,7 @@ ImplFontOptions* PrintFontManager::getFontOptions(
OString sFamily = OUStringToOString( rInfo.m_aFamilyName, RTL_TEXTENCODING_UTF8 );
- boost::unordered_map< OString, OString, OStringHash >::const_iterator aI = rWrapper.m_aLocalizedToCanonical.find(sFamily);
+ std::unordered_map< OString, OString, OStringHash >::const_iterator aI = rWrapper.m_aLocalizedToCanonical.find(sFamily);
if (aI != rWrapper.m_aLocalizedToCanonical.end())
sFamily = aI->second;
if( !sFamily.isEmpty() )
diff --git a/vcl/generic/fontmanager/fontmanager.cxx b/vcl/generic/fontmanager/fontmanager.cxx
index 94165b8f174e..142179fa1068 100644
--- a/vcl/generic/fontmanager/fontmanager.cxx
+++ b/vcl/generic/fontmanager/fontmanager.cxx
@@ -61,9 +61,9 @@
#include "sal/alloca.h"
-#include <set>
-#include <boost/unordered_set.hpp>
#include <algorithm>
+#include <set>
+#include <unordered_set>
#include "adobeenc.tab"
@@ -258,7 +258,7 @@ bool PrintFontManager::TrueTypeFontFile::queryMetricPage( int nPage, MultiAtomPr
*/
static bool familyNameOverride( const OUString& i_rPSname, OUString& o_rFamilyName )
{
- static boost::unordered_map< OUString, OUString, OUStringHash > aPSNameToFamily( 16 );
+ static std::unordered_map< OUString, OUString, OUStringHash > aPSNameToFamily( 16 );
if( aPSNameToFamily.empty() ) // initialization
{
aPSNameToFamily[ "Helvetica-Narrow" ] = "Helvetica Narrow";
@@ -266,7 +266,7 @@ static bool familyNameOverride( const OUString& i_rPSname, OUString& o_rFamilyNa
aPSNameToFamily[ "Helvetica-Narrow-BoldOblique" ] = "Helvetica Narrow";
aPSNameToFamily[ "Helvetica-Narrow-Oblique" ] = "Helvetica Narrow";
}
- boost::unordered_map<OUString,OUString,OUStringHash>::const_iterator it =
+ std::unordered_map<OUString,OUString,OUStringHash>::const_iterator it =
aPSNameToFamily.find( i_rPSname );
bool bReplaced = (it != aPSNameToFamily.end() );
if( bReplaced )
@@ -588,8 +588,8 @@ bool PrintFontManager::PrintFont::readAfmMetrics( MultiAtomProvider* pProvider,
}
else if( pChar->code != -1 )
{
- ::std::pair< ::boost::unordered_multimap< sal_uInt8, sal_Unicode >::const_iterator,
- ::boost::unordered_multimap< sal_uInt8, sal_Unicode >::const_iterator >
+ ::std::pair< std::unordered_multimap< sal_uInt8, sal_Unicode >::const_iterator,
+ std::unordered_multimap< sal_uInt8, sal_Unicode >::const_iterator >
aCodes = rManager.getUnicodeFromAdobeCode( pChar->code );
while( aCodes.first != aCodes.second )
{
@@ -648,12 +648,12 @@ PrintFontManager::PrintFontManager()
{
for( unsigned int i = 0; i < SAL_N_ELEMENTS( aAdobeCodes ); i++ )
{
- m_aUnicodeToAdobename.insert( ::boost::unordered_multimap< sal_Unicode, OString >::value_type( aAdobeCodes[i].aUnicode, aAdobeCodes[i].pAdobename ) );
- m_aAdobenameToUnicode.insert( ::boost::unordered_multimap< OString, sal_Unicode, OStringHash >::value_type( aAdobeCodes[i].pAdobename, aAdobeCodes[i].aUnicode ) );
+ m_aUnicodeToAdobename.insert( std::unordered_multimap< sal_Unicode, OString >::value_type( aAdobeCodes[i].aUnicode, aAdobeCodes[i].pAdobename ) );
+ m_aAdobenameToUnicode.insert( std::unordered_multimap< OString, sal_Unicode, OStringHash >::value_type( aAdobeCodes[i].pAdobename, aAdobeCodes[i].aUnicode ) );
if( aAdobeCodes[i].aAdobeStandardCode )
{
- m_aUnicodeToAdobecode.insert( ::boost::unordered_multimap< sal_Unicode, sal_uInt8 >::value_type( aAdobeCodes[i].aUnicode, aAdobeCodes[i].aAdobeStandardCode ) );
- m_aAdobecodeToUnicode.insert( ::boost::unordered_multimap< sal_uInt8, sal_Unicode >::value_type( aAdobeCodes[i].aAdobeStandardCode, aAdobeCodes[i].aUnicode ) );
+ m_aUnicodeToAdobecode.insert( std::unordered_multimap< sal_Unicode, sal_uInt8 >::value_type( aAdobeCodes[i].aUnicode, aAdobeCodes[i].aAdobeStandardCode ) );
+ m_aAdobecodeToUnicode.insert( std::unordered_multimap< sal_uInt8, sal_Unicode >::value_type( aAdobeCodes[i].aAdobeStandardCode, aAdobeCodes[i].aUnicode ) );
}
}
@@ -665,7 +665,7 @@ PrintFontManager::~PrintFontManager()
{
m_aFontInstallerTimer.Stop();
deinitFontconfig();
- for( ::boost::unordered_map< fontID, PrintFont* >::const_iterator it = m_aFonts.begin(); it != m_aFonts.end(); ++it )
+ for( std::unordered_map< fontID, PrintFont* >::const_iterator it = m_aFonts.begin(); it != m_aFonts.end(); ++it )
delete (*it).second;
delete m_pAtoms;
delete m_pFontCache;
@@ -673,14 +673,14 @@ PrintFontManager::~PrintFontManager()
OString PrintFontManager::getDirectory( int nAtom ) const
{
- ::boost::unordered_map< int, OString >::const_iterator it( m_aAtomToDir.find( nAtom ) );
+ std::unordered_map< int, OString >::const_iterator it( m_aAtomToDir.find( nAtom ) );
return it != m_aAtomToDir.end() ? it->second : OString();
}
int PrintFontManager::getDirectoryAtom( const OString& rDirectory, bool bCreate )
{
int nAtom = 0;
- ::boost::unordered_map< OString, int, OStringHash >::const_iterator it
+ std::unordered_map< OString, int, OStringHash >::const_iterator it
( m_aDirToAtom.find( rDirectory ) );
if( it != m_aDirToAtom.end() )
nAtom = it->second;
@@ -885,13 +885,13 @@ fontID PrintFontManager::findFontFileID( int nDirID, const OString& rFontFile, i
{
fontID nID = 0;
- ::boost::unordered_map< OString, ::std::set< fontID >, OStringHash >::const_iterator set_it = m_aFontFileToFontID.find( rFontFile );
+ std::unordered_map< OString, ::std::set< fontID >, OStringHash >::const_iterator set_it = m_aFontFileToFontID.find( rFontFile );
if( set_it == m_aFontFileToFontID.end() )
return nID;
for( ::std::set< fontID >::const_iterator font_it = set_it->second.begin(); font_it != set_it->second.end() && ! nID; ++font_it )
{
- ::boost::unordered_map< fontID, PrintFont* >::const_iterator it = m_aFonts.find( *font_it );
+ std::unordered_map< fontID, PrintFont* >::const_iterator it = m_aFonts.find( *font_it );
if( it == m_aFonts.end() )
continue;
switch( it->second->m_eType )
@@ -924,13 +924,13 @@ std::vector<fontID> PrintFontManager::findFontFileIDs( int nDirID, const OString
{
std::vector<fontID> aIds;
- ::boost::unordered_map< OString, ::std::set< fontID >, OStringHash >::const_iterator set_it = m_aFontFileToFontID.find( rFontFile );
+ std::unordered_map< OString, ::std::set< fontID >, OStringHash >::const_iterator set_it = m_aFontFileToFontID.find( rFontFile );
if( set_it == m_aFontFileToFontID.end() )
return aIds;
for( ::std::set< fontID >::const_iterator font_it = set_it->second.begin(); font_it != set_it->second.end(); ++font_it )
{
- ::boost::unordered_map< fontID, PrintFont* >::const_iterator it = m_aFonts.find( *font_it );
+ std::unordered_map< fontID, PrintFont* >::const_iterator it = m_aFonts.find( *font_it );
if( it == m_aFonts.end() )
continue;
switch( it->second->m_eType )
@@ -1358,7 +1358,7 @@ void PrintFontManager::initialize()
// gtk-fontconfig-timestamp changes to reflect new font installed and
// PrintFontManager::initialize called again
{
- for( ::boost::unordered_map< fontID, PrintFont* >::const_iterator it = m_aFonts.begin(); it != m_aFonts.end(); ++it )
+ for( std::unordered_map< fontID, PrintFont* >::const_iterator it = m_aFonts.begin(); it != m_aFonts.end(); ++it )
delete (*it).second;
m_nNextFontID = 1;
m_aFonts.clear();
@@ -1410,7 +1410,7 @@ void PrintFontManager::initialize()
}
// protect against duplicate paths
- boost::unordered_map< OString, int, OStringHash > visited_dirs;
+ std::unordered_map< OString, int, OStringHash > visited_dirs;
// Don't search directories that fontconfig already did
countFontconfigFonts( visited_dirs );
@@ -1463,10 +1463,10 @@ void PrintFontManager::initialize()
#endif
// part three - fill in family styles
- ::boost::unordered_map< fontID, PrintFont* >::iterator font_it;
+ std::unordered_map< fontID, PrintFont* >::iterator font_it;
for (font_it = m_aFonts.begin(); font_it != m_aFonts.end(); ++font_it)
{
- ::boost::unordered_map< int, FontFamily >::const_iterator it =
+ std::unordered_map< int, FontFamily >::const_iterator it =
m_aFamilyTypes.find( font_it->second->m_nFamilyName );
if (it != m_aFamilyTypes.end())
continue;
@@ -1495,7 +1495,7 @@ void PrintFontManager::initialize()
void PrintFontManager::getFontList( ::std::list< fontID >& rFontIDs )
{
rFontIDs.clear();
- boost::unordered_map< fontID, PrintFont* >::const_iterator it;
+ std::unordered_map< fontID, PrintFont* >::const_iterator it;
for( it = m_aFonts.begin(); it != m_aFonts.end(); ++it )
rFontIDs.push_back( it->first );
@@ -1503,7 +1503,7 @@ void PrintFontManager::getFontList( ::std::list< fontID >& rFontIDs )
void PrintFontManager::fillPrintFontInfo( PrintFont* pFont, FastPrintFontInfo& rInfo ) const
{
- ::boost::unordered_map< int, FontFamily >::const_iterator style_it =
+ std::unordered_map< int, FontFamily >::const_iterator style_it =
m_aFamilyTypes.find( pFont->m_nFamilyName );
rInfo.m_eType = pFont->m_eType;
rInfo.m_aFamilyName = m_pAtoms->getString( ATOM_FAMILYNAME, pFont->m_nFamilyName );
@@ -1693,7 +1693,7 @@ OString PrintFontManager::getFontFile( PrintFont* pFont ) const
if( pFont && pFont->m_eType == fonttype::Type1 )
{
Type1FontFile* pPSFont = static_cast< Type1FontFile* >(pFont);
- ::boost::unordered_map< int, OString >::const_iterator it = m_aAtomToDir.find( pPSFont->m_nDirectory );
+ std::unordered_map< int, OString >::const_iterator it = m_aAtomToDir.find( pPSFont->m_nDirectory );
aPath = it->second;
aPath += "/";
aPath += pPSFont->m_aFontFile;
@@ -1701,7 +1701,7 @@ OString PrintFontManager::getFontFile( PrintFont* pFont ) const
else if( pFont && pFont->m_eType == fonttype::TrueType )
{
TrueTypeFontFile* pTTFont = static_cast< TrueTypeFontFile* >(pFont);
- ::boost::unordered_map< int, OString >::const_iterator it = m_aAtomToDir.find( pTTFont->m_nDirectory );
+ std::unordered_map< int, OString >::const_iterator it = m_aAtomToDir.find( pTTFont->m_nDirectory );
aPath = it->second;
aPath += "/";
aPath += pTTFont->m_aFontFile;
@@ -1770,7 +1770,7 @@ void PrintFontManager::hasVerticalSubstitutions( fontID nFontID,
if( ! pFont->m_pMetrics ||
! ( pFont->m_pMetrics->m_aPages[ code >> 11 ] & ( 1 << ( ( code >> 8 ) & 7 ) ) ) )
pFont->queryMetricPage( code >> 8, m_pAtoms );
- ::boost::unordered_map< sal_Unicode, bool >::const_iterator it = pFont->m_pMetrics->m_bVerticalSubstitutions.find( code );
+ std::unordered_map< sal_Unicode, bool >::const_iterator it = pFont->m_pMetrics->m_bVerticalSubstitutions.find( code );
pHasSubst[i] = it != pFont->m_pMetrics->m_bVerticalSubstitutions.end();
}
}
@@ -1839,7 +1839,7 @@ bool PrintFontManager::getMetrics( fontID nFontID, const sal_Unicode* pString, i
{
int effectiveCode = pString[i];
effectiveCode |= bVertical ? 1 << 16 : 0;
- ::boost::unordered_map< int, CharacterMetric >::const_iterator it =
+ std::unordered_map< int, CharacterMetric >::const_iterator it =
pFont->m_pMetrics->m_aMetrics.find( effectiveCode );
// if no vertical metrics are available assume rotated horizontal metrics
if( bVertical && (it == pFont->m_pMetrics->m_aMetrics.end()) )
@@ -1886,7 +1886,7 @@ bool PrintFontManager::getMetrics( fontID nFontID, sal_Unicode minCharacter, sal
{
int effectiveCode = code;
effectiveCode |= bVertical ? 1 << 16 : 0;
- ::boost::unordered_map< int, CharacterMetric >::const_iterator it =
+ std::unordered_map< int, CharacterMetric >::const_iterator it =
pFont->m_pMetrics->m_aMetrics.find( effectiveCode );
// if no vertical metrics are available assume rotated horizontal metrics
if( bVertical && (it == pFont->m_pMetrics->m_aMetrics.end()) )
@@ -2124,7 +2124,7 @@ void PrintFontManager::getGlyphWidths( fontID nFont,
rUnicodeEnc.clear();
rWidths.clear();
rWidths.reserve( pFont->m_pMetrics->m_aMetrics.size() );
- for( boost::unordered_map< int, CharacterMetric >::const_iterator it =
+ for( std::unordered_map< int, CharacterMetric >::const_iterator it =
pFont->m_pMetrics->m_aMetrics.begin();
it != pFont->m_pMetrics->m_aMetrics.end(); ++it )
{
@@ -2155,8 +2155,8 @@ const std::map< sal_Unicode, sal_Int32 >* PrintFontManager::getEncodingMap( font
std::list< OString > PrintFontManager::getAdobeNameFromUnicode( sal_Unicode aChar ) const
{
- std::pair< boost::unordered_multimap< sal_Unicode, OString >::const_iterator,
- boost::unordered_multimap< sal_Unicode, OString >::const_iterator > range
+ std::pair< std::unordered_multimap< sal_Unicode, OString >::const_iterator,
+ std::unordered_multimap< sal_Unicode, OString >::const_iterator > range
= m_aUnicodeToAdobename.equal_range( aChar );
std::list< OString > aRet;
@@ -2175,8 +2175,8 @@ std::list< OString > PrintFontManager::getAdobeNameFromUnicode( sal_Unicode aCha
std::list< sal_Unicode > PrintFontManager::getUnicodeFromAdobeName( const OString& rName ) const
{
- std::pair< boost::unordered_multimap< OString, sal_Unicode, OStringHash >::const_iterator,
- boost::unordered_multimap< OString, sal_Unicode, OStringHash >::const_iterator > range
+ std::pair< std::unordered_multimap< OString, sal_Unicode, OStringHash >::const_iterator,
+ std::unordered_multimap< OString, sal_Unicode, OStringHash >::const_iterator > range
= m_aAdobenameToUnicode.equal_range( rName );
std::list< sal_Unicode > aRet;
diff --git a/vcl/generic/glyphs/gcach_ftyp.cxx b/vcl/generic/glyphs/gcach_ftyp.cxx
index 2db0f0d98d34..bdbc0b64146a 100644
--- a/vcl/generic/glyphs/gcach_ftyp.cxx
+++ b/vcl/generic/glyphs/gcach_ftyp.cxx
@@ -93,7 +93,7 @@ static FT_Library aLibFT = 0;
// enable linking with old FT versions
static int nFTVERSION = 0;
-typedef ::boost::unordered_map<const char*, boost::shared_ptr<FtFontFile>, rtl::CStringHash, rtl::CStringEqual> FontFileList;
+typedef std::unordered_map<const char*, boost::shared_ptr<FtFontFile>, rtl::CStringHash, rtl::CStringEqual> FontFileList;
namespace { struct vclFontFileList : public rtl::Static< FontFileList, vclFontFileList > {}; }
diff --git a/vcl/generic/print/glyphset.hxx b/vcl/generic/print/glyphset.hxx
index e6f8fa73c811..41cff1650311 100644
--- a/vcl/generic/print/glyphset.hxx
+++ b/vcl/generic/print/glyphset.hxx
@@ -27,7 +27,7 @@
#include "rtl/string.hxx"
#include <list>
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
class Point;
@@ -47,9 +47,9 @@ private:
rtl_TextEncoding mnBaseEncoding;
bool mbUseFontEncoding;
- typedef boost::unordered_map< sal_Unicode, sal_uInt8 > char_map_t;
+ typedef std::unordered_map< sal_Unicode, sal_uInt8 > char_map_t;
typedef std::list< char_map_t > char_list_t;
- typedef boost::unordered_map< sal_GlyphId, sal_uInt8 > glyph_map_t;
+ typedef std::unordered_map< sal_GlyphId, sal_uInt8 > glyph_map_t;
typedef std::list< glyph_map_t > glyph_list_t;
char_list_t maCharList;
diff --git a/vcl/inc/PhysicalFontCollection.hxx b/vcl/inc/PhysicalFontCollection.hxx
index 86488fcebef5..28e18071ddb3 100644
--- a/vcl/inc/PhysicalFontCollection.hxx
+++ b/vcl/inc/PhysicalFontCollection.hxx
@@ -37,7 +37,7 @@ private:
mutable bool mbMatchData; // true if matching attributes are initialized
bool mbMapNames; // true if MapNames are available
- typedef boost::unordered_map<const OUString, PhysicalFontFamily*,OUStringHash> PhysicalFontFamilies;
+ typedef std::unordered_map<const OUString, PhysicalFontFamily*,OUStringHash> PhysicalFontFamilies;
PhysicalFontFamilies maPhysicalFontFamilies;
ImplPreMatchFontSubstitution* mpPreMatchHook; // device specific prematch substitution
diff --git a/vcl/inc/cupsmgr.hxx b/vcl/inc/cupsmgr.hxx
index 12beba4d365c..c7b948737f05 100644
--- a/vcl/inc/cupsmgr.hxx
+++ b/vcl/inc/cupsmgr.hxx
@@ -38,13 +38,13 @@ struct FPtrHash
class CUPSManager : public PrinterInfoManager
{
- boost::unordered_map< FILE*, OString, FPtrHash > m_aSpoolFiles;
- int m_nDests;
- void* m_pDests;
- bool m_bNewDests;
- boost::unordered_map< OUString, int, OUStringHash > m_aCUPSDestMap;
+ std::unordered_map< FILE*, OString, FPtrHash > m_aSpoolFiles;
+ int m_nDests;
+ void* m_pDests;
+ bool m_bNewDests;
+ std::unordered_map< OUString, int, OUStringHash > m_aCUPSDestMap;
- boost::unordered_map< OUString, PPDContext, OUStringHash > m_aDefaultContexts;
+ std::unordered_map< OUString, PPDContext, OUStringHash > m_aDefaultContexts;
OString m_aUser;
/** this is a security risk, but the CUPS API demands
diff --git a/vcl/inc/fontcache.hxx b/vcl/inc/fontcache.hxx
index 777c896face3..98d9029b6be9 100644
--- a/vcl/inc/fontcache.hxx
+++ b/vcl/inc/fontcache.hxx
@@ -22,7 +22,7 @@
#include <rtl/ustring.hxx>
#include <vcl/dllapi.h>
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
#include "fontmanager.hxx"
@@ -42,7 +42,7 @@ class VCL_PLUGIN_PUBLIC FontCache
FontCacheEntry m_aEntry;
};
- typedef boost::unordered_map< OString, FontFile, OStringHash > FontDirMap;
+ typedef std::unordered_map< OString, FontFile, OStringHash > FontDirMap;
struct FontDir
{
sal_Int64 m_nTimestamp;
@@ -53,7 +53,7 @@ class VCL_PLUGIN_PUBLIC FontCache
FontDir() : m_nTimestamp(0), m_bNoFiles(false), m_bUserOverrideOnly( false ) {}
};
- typedef boost::unordered_map< int, FontDir > FontCacheData;
+ typedef std::unordered_map< int, FontDir > FontCacheData;
FontCacheData m_aCache;
OUString m_aCacheFile;
bool m_bDoFlush;
diff --git a/vcl/inc/fontmanager.hxx b/vcl/inc/fontmanager.hxx
index e1203bd83a90..beec12ad838f 100644
--- a/vcl/inc/fontmanager.hxx
+++ b/vcl/inc/fontmanager.hxx
@@ -20,10 +20,10 @@
#ifndef INCLUDED_VCL_INC_FONTMANAGER_HXX
#define INCLUDED_VCL_INC_FONTMANAGER_HXX
-#include <boost/unordered_map.hpp>
-#include <map>
#include <list>
+#include <map>
#include <set>
+#include <unordered_map>
#include <vcl/dllapi.h>
#include <vcl/helper.hxx>
@@ -155,7 +155,7 @@ class VCL_PLUGIN_PUBLIC PrintFontManager
// upper byte contains: 0 for horizontal metric
// 1 for vertical metric
// highest byte: 0 for now
- boost::unordered_map< int, CharacterMetric > m_aMetrics;
+ std::unordered_map< int, CharacterMetric > m_aMetrics;
// contains the unicode blocks for which metrics were queried
// this implies that metrics should be queried in terms of
// unicode blocks. here a unicode block is identified
@@ -167,7 +167,7 @@ class VCL_PLUGIN_PUBLIC PrintFontManager
// a single pass, then all bits should be set
char m_aPages[32];
- boost::unordered_map< sal_Unicode, bool > m_bVerticalSubstitutions;
+ std::unordered_map< sal_Unicode, bool > m_bVerticalSubstitutions;
PrintFontMetrics() {}
@@ -239,27 +239,27 @@ class VCL_PLUGIN_PUBLIC PrintFontManager
};
fontID m_nNextFontID;
- boost::unordered_map< fontID, PrintFont* > m_aFonts;
- boost::unordered_map< int, FontFamily > m_aFamilyTypes;
+ std::unordered_map< fontID, PrintFont* > m_aFonts;
+ std::unordered_map< int, FontFamily > m_aFamilyTypes;
std::list< OUString > m_aPrinterDrivers;
std::list< OString > m_aFontDirectories;
std::list< int > m_aPrivateFontDirectories;
utl::MultiAtomProvider* m_pAtoms;
// for speeding up findFontFileID
- boost::unordered_map< OString, std::set< fontID >, OStringHash >
+ std::unordered_map< OString, std::set< fontID >, OStringHash >
m_aFontFileToFontID;
- boost::unordered_map< OString, int, OStringHash >
+ std::unordered_map< OString, int, OStringHash >
m_aDirToAtom;
- boost::unordered_map< int, OString > m_aAtomToDir;
+ std::unordered_map< int, OString > m_aAtomToDir;
int m_nNextDirAtom;
- boost::unordered_multimap< OString, sal_Unicode, OStringHash >
+ std::unordered_multimap< OString, sal_Unicode, OStringHash >
m_aAdobenameToUnicode;
- boost::unordered_multimap< sal_Unicode, OString >
+ std::unordered_multimap< sal_Unicode, OString >
m_aUnicodeToAdobename;
- boost::unordered_multimap< sal_Unicode, sal_uInt8 > m_aUnicodeToAdobecode;
- boost::unordered_multimap< sal_uInt8, sal_Unicode > m_aAdobecodeToUnicode;
+ std::unordered_multimap< sal_Unicode, sal_uInt8 > m_aUnicodeToAdobecode;
+ std::unordered_multimap< sal_uInt8, sal_Unicode > m_aAdobecodeToUnicode;
mutable FontCache* m_pFontCache;
@@ -286,7 +286,7 @@ class VCL_PLUGIN_PUBLIC PrintFontManager
PrintFont* getFont( fontID nID ) const
{
- boost::unordered_map< fontID, PrintFont* >::const_iterator it;
+ std::unordered_map< fontID, PrintFont* >::const_iterator it;
it = m_aFonts.find( nID );
return it == m_aFonts.end() ? NULL : it->second;
}
@@ -301,7 +301,7 @@ class VCL_PLUGIN_PUBLIC PrintFontManager
called from <code>initialize()</code>
*/
void initFontconfig();
- void countFontconfigFonts( boost::unordered_map<OString, int, OStringHash>& o_rVisitedPaths );
+ void countFontconfigFonts( std::unordered_map<OString, int, OStringHash>& o_rVisitedPaths );
/* deinitialize fontconfig
*/
void deinitFontconfig();
@@ -447,15 +447,15 @@ public:
// helper for type 1 fonts
std::list< OString > getAdobeNameFromUnicode( sal_Unicode aChar ) const;
- std::pair< boost::unordered_multimap< sal_Unicode, sal_uInt8 >::const_iterator,
- boost::unordered_multimap< sal_Unicode, sal_uInt8 >::const_iterator >
+ std::pair< std::unordered_multimap< sal_Unicode, sal_uInt8 >::const_iterator,
+ std::unordered_multimap< sal_Unicode, sal_uInt8 >::const_iterator >
getAdobeCodeFromUnicode( sal_Unicode aChar ) const
{
return m_aUnicodeToAdobecode.equal_range( aChar );
}
std::list< sal_Unicode > getUnicodeFromAdobeName( const OString& rName ) const;
- std::pair< boost::unordered_multimap< sal_uInt8, sal_Unicode >::const_iterator,
- boost::unordered_multimap< sal_uInt8, sal_Unicode >::const_iterator >
+ std::pair< std::unordered_multimap< sal_uInt8, sal_Unicode >::const_iterator,
+ std::unordered_multimap< sal_uInt8, sal_Unicode >::const_iterator >
getUnicodeFromAdobeCode( sal_uInt8 aChar ) const
{
return m_aAdobecodeToUnicode.equal_range( aChar );
diff --git a/vcl/inc/generic/glyphcache.hxx b/vcl/inc/generic/glyphcache.hxx
index ddfc7a8ef965..4133cd8689d8 100644
--- a/vcl/inc/generic/glyphcache.hxx
+++ b/vcl/inc/generic/glyphcache.hxx
@@ -27,7 +27,6 @@
#include FT_GLYPH_H
#include <boost/shared_ptr.hpp>
-#include <boost/unordered_map.hpp>
#include <basebmp/bitmapdevice.hxx>
#include <com/sun/star/i18n/XBreakIterator.hpp>
@@ -38,6 +37,8 @@
#include <outfont.hxx>
#include <sallayout.hxx>
+#include <unordered_map>
+
class FtFontInfo;
class GlyphCachePeer;
class GlyphData;
@@ -87,7 +88,7 @@ private:
// the FontList key's mpFontData member is reinterpreted as integer font id
struct IFSD_Equal{ bool operator()( const FontSelectPattern&, const FontSelectPattern& ) const; };
struct IFSD_Hash{ size_t operator()( const FontSelectPattern& ) const; };
- typedef ::boost::unordered_map<FontSelectPattern,ServerFont*,IFSD_Hash,IFSD_Equal > FontList;
+ typedef std::unordered_map<FontSelectPattern,ServerFont*,IFSD_Hash,IFSD_Equal > FontList;
FontList maFontList;
sal_uLong mnMaxSize; // max overall cache size in bytes
mutable sal_uLong mnBytesUsed;
@@ -221,7 +222,7 @@ private:
ServerFontLayoutEngine* GetLayoutEngine();
- typedef ::boost::unordered_map<int,GlyphData> GlyphList;
+ typedef std::unordered_map<int,GlyphData> GlyphList;
mutable GlyphList maGlyphList;
const FontSelectPattern maFontSelData;
@@ -256,7 +257,7 @@ private:
bool mbArtBold;
bool mbUseGamma;
- typedef ::boost::unordered_map<int,int> GlyphSubstitution;
+ typedef std::unordered_map<int,int> GlyphSubstitution;
GlyphSubstitution maGlyphSubstitution;
ServerFontLayoutEngine* mpLayoutEngine;
diff --git a/vcl/inc/generic/printergfx.hxx b/vcl/inc/generic/printergfx.hxx
index a0e2683ce6b2..aa7f87ce4876 100644
--- a/vcl/inc/generic/printergfx.hxx
+++ b/vcl/inc/generic/printergfx.hxx
@@ -27,7 +27,6 @@
#include "vclpluginapi.h"
#include <list>
-#include <boost/unordered_map.hpp>
namespace psp {
diff --git a/vcl/inc/headless/svpinst.hxx b/vcl/inc/headless/svpinst.hxx
index 0bf542fccd2b..2e2d8339c7f8 100644
--- a/vcl/inc/headless/svpinst.hxx
+++ b/vcl/inc/headless/svpinst.hxx
@@ -30,6 +30,7 @@
#include <basebmp/scanlineformats.hxx>
#include <list>
+#include <map>
#include <time.h>
diff --git a/vcl/inc/image.h b/vcl/inc/image.h
index d9de98caa13f..b9767ce0362c 100644
--- a/vcl/inc/image.h
+++ b/vcl/inc/image.h
@@ -22,7 +22,7 @@
#include <vcl/bitmapex.hxx>
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
// - ImplImageBmp -
@@ -81,7 +81,7 @@ struct ImageAryData
struct ImplImageList
{
typedef std::vector<ImageAryData *> ImageAryDataVec;
- typedef boost::unordered_map< OUString, ImageAryData *, OUStringHash >
+ typedef std::unordered_map< OUString, ImageAryData *, OUStringHash >
ImageAryDataNameHash;
ImageAryDataVec maImages;
diff --git a/vcl/inc/impimagetree.hxx b/vcl/inc/impimagetree.hxx
index e66e754a1c8d..0fbb2769e086 100644
--- a/vcl/inc/impimagetree.hxx
+++ b/vcl/inc/impimagetree.hxx
@@ -22,10 +22,9 @@
#include "sal/config.h"
+#include <unordered_map>
#include <vector>
-#include <boost/unordered_map.hpp>
-
#include "boost/noncopyable.hpp"
#include "com/sun/star/uno/Reference.hxx"
#include "rtl/ustring.hxx"
@@ -58,8 +57,8 @@ public:
css::uno::Reference< css::container::XNameAccess > getNameAccess();
private:
- typedef boost::unordered_map<OUString, std::pair<bool, BitmapEx>, OUStringHash> IconCache;
- typedef boost::unordered_map<OUString, OUString, OUStringHash> IconLinkHash;
+ typedef std::unordered_map<OUString, std::pair<bool, BitmapEx>, OUStringHash> IconCache;
+ typedef std::unordered_map<OUString, OUString, OUStringHash> IconLinkHash;
struct IconSet {
OUString maURL;
@@ -72,7 +71,7 @@ private:
};
/// Map between the theme name(s) and the content.
- typedef boost::unordered_map<OUString, IconSet, OUStringHash> StyleIconSet;
+ typedef std::unordered_map<OUString, IconSet, OUStringHash> StyleIconSet;
/// Remember all the (used) icon styles and individual icons in them.
StyleIconSet maIconSet;
diff --git a/vcl/inc/jobset.h b/vcl/inc/jobset.h
index c62440773d57..e1ba5bbe629e 100644
--- a/vcl/inc/jobset.h
+++ b/vcl/inc/jobset.h
@@ -20,9 +20,9 @@
#ifndef INCLUDED_VCL_INC_JOBSET_H
#define INCLUDED_VCL_INC_JOBSET_H
-#include <boost/unordered_map.hpp>
#include <rtl/ustring.hxx>
#include <vcl/prntypes.hxx>
+#include <unordered_map>
// see com.sun.star.portal.client.JobSetupSystem.idl:
#define JOBSETUP_SYSTEM_DONTKNOW 0
@@ -46,7 +46,7 @@ struct ImplJobSetup
long mnPaperHeight; // paper height (100th mm)
sal_uIntPtr mnDriverDataLen; // length of system specific data
sal_uInt8* mpDriverData; // system specific data (will be streamed a byte block)
- ::boost::unordered_map< OUString, OUString, OUStringHash > maValueMap;
+ std::unordered_map< OUString, OUString, OUStringHash > maValueMap;
ImplJobSetup();
ImplJobSetup( const ImplJobSetup& rJobSetup );
diff --git a/vcl/inc/opengl/program.hxx b/vcl/inc/opengl/program.hxx
index 996bc61b275c..6e21abfd1129 100644
--- a/vcl/inc/opengl/program.hxx
+++ b/vcl/inc/opengl/program.hxx
@@ -22,9 +22,9 @@
#include <tools/color.hxx>
#include <opengl/texture.hxx>
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
-typedef boost::unordered_map< OString, GLuint, OStringHash > UniformCache;
+typedef std::unordered_map< OString, GLuint, OStringHash > UniformCache;
typedef std::list< OpenGLTexture > TextureList;
class VCL_PLUGIN_PUBLIC OpenGLProgram
diff --git a/vcl/inc/outdev.h b/vcl/inc/outdev.h
index c878d8b2590d..bcb64f23dde1 100644
--- a/vcl/inc/outdev.h
+++ b/vcl/inc/outdev.h
@@ -140,7 +140,7 @@ private:
// cache of recently used font instances
struct IFSD_Equal { bool operator()( const FontSelectPattern&, const FontSelectPattern& ) const; };
struct IFSD_Hash { size_t operator()( const FontSelectPattern& ) const; };
- typedef ::boost::unordered_map<FontSelectPattern,ImplFontEntry*,IFSD_Hash,IFSD_Equal > FontInstanceList;
+ typedef std::unordered_map<FontSelectPattern,ImplFontEntry*,IFSD_Hash,IFSD_Equal > FontInstanceList;
FontInstanceList maFontInstanceList;
public:
diff --git a/vcl/inc/outfont.hxx b/vcl/inc/outfont.hxx
index 0f28657aed0d..69de06ac1cf9 100644
--- a/vcl/inc/outfont.hxx
+++ b/vcl/inc/outfont.hxx
@@ -28,7 +28,7 @@
#include <unotools/fontdefs.hxx>
#include <vcl/vclenum.hxx>
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
class PhysicalFontFace;
class PhysicalFontFamily;
@@ -246,7 +246,7 @@ private:
// TODO: at least the ones which just differ in orientation, stretching or height
typedef ::std::pair<sal_UCS4,FontWeight> GFBCacheKey;
struct GFBCacheKey_Hash{ size_t operator()( const GFBCacheKey& ) const; };
- typedef ::boost::unordered_map<GFBCacheKey,OUString,GFBCacheKey_Hash> UnicodeFallbackList;
+ typedef ::std::unordered_map<GFBCacheKey,OUString,GFBCacheKey_Hash> UnicodeFallbackList;
UnicodeFallbackList* mpUnicodeFallbackList;
};
diff --git a/vcl/inc/print.h b/vcl/inc/print.h
index 2aa3c6b4a370..7eec4216eb63 100644
--- a/vcl/inc/print.h
+++ b/vcl/inc/print.h
@@ -23,7 +23,7 @@
#include "rtl/ustring.hxx"
#include "vcl/dllapi.h"
#include <vector>
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
struct SalPrinterQueueInfo;
class QueueInfo;
@@ -41,7 +41,7 @@ struct ImplPrnQueueData
class VCL_PLUGIN_PUBLIC ImplPrnQueueList
{
public:
- boost::unordered_map< OUString, sal_Int32, OUStringHash >
+ std::unordered_map< OUString, sal_Int32, OUStringHash >
m_aNameToIndex;
std::vector< ImplPrnQueueData > m_aQueueInfos;
std::vector< OUString > m_aPrinterList;
diff --git a/vcl/inc/svdata.hxx b/vcl/inc/svdata.hxx
index 683f40d908fb..9d20196d07b5 100644
--- a/vcl/inc/svdata.hxx
+++ b/vcl/inc/svdata.hxx
@@ -43,7 +43,7 @@
#include "com/sun/star/lang/XComponent.hpp"
#include "com/sun/star/uno/Reference.hxx"
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
#include <config_version.h>
@@ -336,7 +336,7 @@ struct ImplSVData
::com::sun::star::uno::Reference< ::com::sun::star::lang::XComponent > mxAccessBridge;
::vcl::SettingsConfigItem* mpSettingsConfigItem;
std::list< vcl::DeleteOnDeinitBase* >* mpDeinitDeleteList;
- boost::unordered_map< int, OUString >* mpPaperNames;
+ std::unordered_map< int, OUString >* mpPaperNames;
Link maDeInitHook;
};
diff --git a/vcl/inc/unx/saldisp.hxx b/vcl/inc/unx/saldisp.hxx
index 8b56e18c0924..acaa1fd7065a 100644
--- a/vcl/inc/unx/saldisp.hxx
+++ b/vcl/inc/unx/saldisp.hxx
@@ -31,9 +31,9 @@ class SalXLib;
#include <vcl/ptrstyle.hxx>
#include <sal/types.h>
#include <osl/mutex.h>
-#include <vector>
#include <list>
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
+#include <vector>
#include <tools/gen.hxx>
#include <salwtype.hxx>
#include <generic/gendata.hxx>
@@ -204,7 +204,7 @@ public:
RenderEntry() : m_aPixmap( 0 ), m_aPicture( 0 ) {}
};
- typedef boost::unordered_map<int,RenderEntry> RenderEntryMap;
+ typedef std::unordered_map<int,RenderEntry> RenderEntryMap;
struct ScreenData
{
diff --git a/vcl/inc/unx/salinst.h b/vcl/inc/unx/salinst.h
index cea08dd6da96..c2df7a87f182 100644
--- a/vcl/inc/unx/salinst.h
+++ b/vcl/inc/unx/salinst.h
@@ -37,7 +37,7 @@ class SalXLib;
class VCLPLUG_GEN_PUBLIC X11SalInstance : public SalGenericInstance
{
private:
- boost::unordered_map< Atom, com::sun::star::uno::Reference< com::sun::star::datatransfer::clipboard::XClipboard > > m_aInstances;
+ std::unordered_map< Atom, com::sun::star::uno::Reference< com::sun::star::datatransfer::clipboard::XClipboard > > m_aInstances;
protected:
SalXLib *mpXLib;
diff --git a/vcl/opengl/program.cxx b/vcl/opengl/program.cxx
index 434b72482a8b..0fe460592007 100644
--- a/vcl/opengl/program.cxx
+++ b/vcl/opengl/program.cxx
@@ -113,9 +113,7 @@ void OpenGLProgram::SetAlphaCoord( const GLvoid* pData )
GLuint OpenGLProgram::GetUniformLocation( const OString& rName )
{
- boost::unordered_map<OString, GLuint>::iterator it;
-
- it = maUniformLocations.find( rName );
+ auto it = maUniformLocations.find( rName );
if( it == maUniformLocations.end() )
{
GLuint nLocation = glGetUniformLocation( mnId, (char*) rName.getStr() );
diff --git a/vcl/source/control/tabctrl.cxx b/vcl/source/control/tabctrl.cxx
index e36acc02ac54..5bebdbee5a8f 100644
--- a/vcl/source/control/tabctrl.cxx
+++ b/vcl/source/control/tabctrl.cxx
@@ -36,7 +36,7 @@
#include "svdata.hxx"
#include "window.h"
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
#include <vector>
struct ImplTabItem
@@ -62,8 +62,8 @@ struct ImplTabItem
struct ImplTabCtrlData
{
- boost::unordered_map< int, int > maLayoutPageIdToLine;
- boost::unordered_map< int, int > maLayoutLineToPageId;
+ std::unordered_map< int, int > maLayoutPageIdToLine;
+ std::unordered_map< int, int > maLayoutLineToPageId;
std::vector< Rectangle > maTabRectangles;
Point maItemsOffset; // offset of the tabitems
std::vector< ImplTabItem > maItemList;
@@ -2025,7 +2025,7 @@ Rectangle TabControl::GetCharacterBounds( sal_uInt16 nPageId, long nIndex ) cons
if( HasLayoutData() )
{
- boost::unordered_map< int, int >::const_iterator it = mpTabCtrlData->maLayoutPageIdToLine.find( (int)nPageId );
+ std::unordered_map< int, int >::const_iterator it = mpTabCtrlData->maLayoutPageIdToLine.find( (int)nPageId );
if( it != mpTabCtrlData->maLayoutPageIdToLine.end() )
{
Pair aPair = mpControlData->mpLayoutData->GetLineStartEnd( it->second );
diff --git a/vcl/source/gdi/configsettings.cxx b/vcl/source/gdi/configsettings.cxx
index 72b11592029d..8e1c5d9b5aaa 100644
--- a/vcl/source/gdi/configsettings.cxx
+++ b/vcl/source/gdi/configsettings.cxx
@@ -59,7 +59,7 @@ SettingsConfigItem::~SettingsConfigItem()
void SettingsConfigItem::Commit()
{
- boost::unordered_map< OUString, SmallOUStrMap, OUStringHash >::const_iterator group;
+ std::unordered_map< OUString, SmallOUStrMap, OUStringHash >::const_iterator group;
for( group = m_aSettings.begin(); group != m_aSettings.end(); ++group )
{
@@ -136,7 +136,7 @@ void SettingsConfigItem::getValues()
const OUString& SettingsConfigItem::getValue( const OUString& rGroup, const OUString& rKey ) const
{
- ::boost::unordered_map< OUString, SmallOUStrMap, OUStringHash >::const_iterator group = m_aSettings.find( rGroup );
+ std::unordered_map< OUString, SmallOUStrMap, OUStringHash >::const_iterator group = m_aSettings.find( rGroup );
if( group == m_aSettings.end() || group->second.find( rKey ) == group->second.end() )
{
static OUString aEmpty;
diff --git a/vcl/source/gdi/jobset.cxx b/vcl/source/gdi/jobset.cxx
index d9fca2276d57..f376d14a5262 100644
--- a/vcl/source/gdi/jobset.cxx
+++ b/vcl/source/gdi/jobset.cxx
@@ -342,7 +342,7 @@ SvStream& WriteJobSetup( SvStream& rOStream, const JobSetup& rJobSetup )
rOStream.Write( (char*)&aOldData, sizeof( aOldData ) );
rOStream.Write( (char*)&aOldJobData, nOldJobDataSize );
rOStream.Write( (char*)pJobData->mpDriverData, pJobData->mnDriverDataLen );
- ::boost::unordered_map< OUString, OUString, OUStringHash >::const_iterator it;
+ std::unordered_map< OUString, OUString, OUStringHash >::const_iterator it;
for( it = pJobData->maValueMap.begin(); it != pJobData->maValueMap.end(); ++it )
{
write_uInt16_lenPrefixed_uInt8s_FromOUString(rOStream, it->first, RTL_TEXTENCODING_UTF8);
diff --git a/vcl/source/gdi/pdfwriter_impl.cxx b/vcl/source/gdi/pdfwriter_impl.cxx
index 72c8f2eff7cc..01931775d2dc 100644
--- a/vcl/source/gdi/pdfwriter_impl.cxx
+++ b/vcl/source/gdi/pdfwriter_impl.cxx
@@ -700,7 +700,7 @@ void PDFWriterImpl::createWidgetFieldName( sal_Int32 i_nWidgetIndex, const PDFWr
// find or create a hierarchical field
// first find the fully qualified name up to this field
aDomain = aFullName.copy( 0, nTokenIndex-1 );
- boost::unordered_map< OString, sal_Int32, OStringHash >::const_iterator it = m_aFieldNameMap.find( aDomain );
+ std::unordered_map< OString, sal_Int32, OStringHash >::const_iterator it = m_aFieldNameMap.find( aDomain );
if( it == m_aFieldNameMap.end() )
{
// create new hierarchy field
@@ -761,7 +761,7 @@ void PDFWriterImpl::createWidgetFieldName( sal_Int32 i_nWidgetIndex, const PDFWr
// insert widget into its hierarchy field
if( !aDomain.isEmpty() )
{
- boost::unordered_map< OString, sal_Int32, OStringHash >::const_iterator it = m_aFieldNameMap.find( aDomain );
+ std::unordered_map< OString, sal_Int32, OStringHash >::const_iterator it = m_aFieldNameMap.find( aDomain );
if( it != m_aFieldNameMap.end() )
{
OSL_ENSURE( it->second >= 0 && it->second < sal_Int32( m_aWidgets.size() ), "invalid field index" );
@@ -788,11 +788,11 @@ void PDFWriterImpl::createWidgetFieldName( sal_Int32 i_nWidgetIndex, const PDFWr
if( ! m_aContext.AllowDuplicateFieldNames )
{
- boost::unordered_map<OString, sal_Int32, OStringHash>::iterator it = m_aFieldNameMap.find( aFullName );
+ std::unordered_map<OString, sal_Int32, OStringHash>::iterator it = m_aFieldNameMap.find( aFullName );
if( it != m_aFieldNameMap.end() ) // not unique
{
- boost::unordered_map< OString, sal_Int32, OStringHash >::const_iterator check_it;
+ std::unordered_map< OString, sal_Int32, OStringHash >::const_iterator check_it;
OString aTry;
sal_Int32 nTry = 2;
do
@@ -2695,7 +2695,7 @@ sal_Int32 PDFWriterImpl::emitStructure( PDFStructureElement& rEle )
if( ! m_aRoleMap.empty() )
{
aLine.append( "/RoleMap<<" );
- for( boost::unordered_map<OString,OString,OStringHash>::const_iterator
+ for( std::unordered_map<OString,OString,OStringHash>::const_iterator
it = m_aRoleMap.begin(); it != m_aRoleMap.end(); ++it )
{
aLine.append( '/' );
@@ -6948,7 +6948,7 @@ void PDFWriterImpl::sortWidgets()
{
// sort widget annotations on each page as per their
// TabOrder attribute
- boost::unordered_map< sal_Int32, AnnotSortContainer > sorted;
+ std::unordered_map< sal_Int32, AnnotSortContainer > sorted;
int nWidgets = m_aWidgets.size();
for( int nW = 0; nW < nWidgets; nW++ )
{
@@ -6968,7 +6968,7 @@ void PDFWriterImpl::sortWidgets()
}
}
}
- for( boost::unordered_map< sal_Int32, AnnotSortContainer >::iterator it = sorted.begin(); it != sorted.end(); ++it )
+ for( std::unordered_map< sal_Int32, AnnotSortContainer >::iterator it = sorted.begin(); it != sorted.end(); ++it )
{
// append entries for non widget annotations
PDFPage& rPage = m_aPages[ it->first ];
@@ -11920,7 +11920,7 @@ void PDFWriterImpl::ensureUniqueRadioOnValues()
{
PDFWidget& rGroupWidget = m_aWidgets[ group->second ];
// check whether all kids have a unique OnValue
- boost::unordered_map< OUString, sal_Int32, OUStringHash > aOnValues;
+ std::unordered_map< OUString, sal_Int32, OUStringHash > aOnValues;
int nChildren = rGroupWidget.m_aKidsIndex.size();
bool bIsUnique = true;
for( int nKid = 0; nKid < nChildren && bIsUnique; nKid++ )
diff --git a/vcl/source/gdi/pdfwriter_impl.hxx b/vcl/source/gdi/pdfwriter_impl.hxx
index 7b294a421f17..43bb0c5d5759 100644
--- a/vcl/source/gdi/pdfwriter_impl.hxx
+++ b/vcl/source/gdi/pdfwriter_impl.hxx
@@ -19,10 +19,10 @@
#ifndef INCLUDED_VCL_SOURCE_GDI_PDFWRITER_IMPL_HXX
#define INCLUDED_VCL_SOURCE_GDI_PDFWRITER_IMPL_HXX
-#include <vector>
#include <map>
-#include <boost/unordered_map.hpp>
#include <list>
+#include <unordered_map>
+#include <vector>
#include <boost/shared_array.hpp>
#include <com/sun/star/lang/Locale.hpp>
@@ -437,8 +437,8 @@ public:
{}
};
- typedef boost::unordered_map< OString, SvMemoryStream*, OStringHash > PDFAppearanceStreams;
- typedef boost::unordered_map< OString, PDFAppearanceStreams, OStringHash > PDFAppearanceMap;
+ typedef std::unordered_map< OString, SvMemoryStream*, OStringHash > PDFAppearanceStreams;
+ typedef std::unordered_map< OString, PDFAppearanceStreams, OStringHash > PDFAppearanceMap;
struct PDFWidget : public PDFAnnotation
{
@@ -643,7 +643,7 @@ private:
bool m_bEmitStructure;
bool m_bNewMCID;
/* role map of struct tree root */
- boost::unordered_map< OString, OString, OStringHash >
+ std::unordered_map< OString, OString, OStringHash >
m_aRoleMap;
/* contains all widgets used in the PDF
@@ -651,8 +651,8 @@ private:
std::vector<PDFWidget> m_aWidgets;
/* maps radio group id to index of radio group control in m_aWidgets */
std::map< sal_Int32, sal_Int32 > m_aRadioGroupWidgets;
- /* boost::unordered_map for field names, used to ensure unique field names */
- boost::unordered_map< OString, sal_Int32, OStringHash > m_aFieldNameMap;
+ /* unordered_map for field names, used to ensure unique field names */
+ std::unordered_map< OString, sal_Int32, OStringHash > m_aFieldNameMap;
/* contains Bitmaps for gradient functions until they are written
* to the file stream */
diff --git a/vcl/source/gdi/print.cxx b/vcl/source/gdi/print.cxx
index f6dd207f679f..3fec08f330b0 100644
--- a/vcl/source/gdi/print.cxx
+++ b/vcl/source/gdi/print.cxx
@@ -438,7 +438,7 @@ ImplPrnQueueList::~ImplPrnQueueList()
void ImplPrnQueueList::Add( SalPrinterQueueInfo* pData )
{
- boost::unordered_map< OUString, sal_Int32, OUStringHash >::iterator it =
+ std::unordered_map< OUString, sal_Int32, OUStringHash >::iterator it =
m_aNameToIndex.find( pData->maPrinterName );
if( it == m_aNameToIndex.end() )
{
@@ -461,7 +461,7 @@ void ImplPrnQueueList::Add( SalPrinterQueueInfo* pData )
ImplPrnQueueData* ImplPrnQueueList::Get( const OUString& rPrinter )
{
ImplPrnQueueData* pData = NULL;
- boost::unordered_map<OUString,sal_Int32,OUStringHash>::iterator it =
+ std::unordered_map<OUString,sal_Int32,OUStringHash>::iterator it =
m_aNameToIndex.find( rPrinter );
if( it != m_aNameToIndex.end() )
pData = &m_aQueueInfos[it->second];
@@ -1554,7 +1554,7 @@ OUString Printer::GetPaperName( Paper ePaper )
ImplSVData* pSVData = ImplGetSVData();
if( ! pSVData->mpPaperNames )
{
- pSVData->mpPaperNames = new boost::unordered_map< int, OUString >();
+ pSVData->mpPaperNames = new std::unordered_map< int, OUString >();
if( ImplGetResMgr() )
{
ResStringArray aPaperStrings( VclResId( RID_STR_PAPERNAMES ) );
@@ -1575,7 +1575,7 @@ OUString Printer::GetPaperName( Paper ePaper )
}
}
- boost::unordered_map<int,OUString>::const_iterator it = pSVData->mpPaperNames->find( (int)ePaper );
+ std::unordered_map<int,OUString>::const_iterator it = pSVData->mpPaperNames->find( (int)ePaper );
return (it != pSVData->mpPaperNames->end()) ? it->second : OUString();
}
diff --git a/vcl/source/gdi/print3.cxx b/vcl/source/gdi/print3.cxx
index 369c8fb47ace..16caf5262b8a 100644
--- a/vcl/source/gdi/print3.cxx
+++ b/vcl/source/gdi/print3.cxx
@@ -42,8 +42,8 @@
#include "com/sun/star/awt/Size.hpp"
#include "comphelper/processfactory.hxx"
-#include <boost/unordered_map.hpp>
-#include <boost/unordered_set.hpp>
+#include <unordered_map>
+#include <unordered_set>
using namespace com::sun::star;
using namespace com::sun::star::uno;
@@ -136,9 +136,9 @@ public:
ControlDependency() : mnDependsOnEntry( -1 ) {}
};
- typedef boost::unordered_map< OUString, size_t, OUStringHash > PropertyToIndexMap;
- typedef boost::unordered_map< OUString, ControlDependency, OUStringHash > ControlDependencyMap;
- typedef boost::unordered_map< OUString, Sequence< sal_Bool >, OUStringHash > ChoiceDisableMap;
+ typedef std::unordered_map< OUString, size_t, OUStringHash > PropertyToIndexMap;
+ typedef std::unordered_map< OUString, ControlDependency, OUStringHash > ControlDependencyMap;
+ typedef std::unordered_map< OUString, Sequence< sal_Bool >, OUStringHash > ChoiceDisableMap;
boost::shared_ptr<Printer> mpPrinter;
Sequence< PropertyValue > maUIOptions;
@@ -1358,7 +1358,7 @@ bool PrinterController::getPapersizeFromSetup() const
Sequence< PropertyValue > PrinterController::getJobProperties( const Sequence< PropertyValue >& i_rMergeList ) const
{
- boost::unordered_set< OUString, OUStringHash > aMergeSet;
+ std::unordered_set< OUString, OUStringHash > aMergeSet;
size_t nResultLen = size_t(i_rMergeList.getLength()) + mpImplData->maUIProperties.size() + 3;
for( int i = 0; i < i_rMergeList.getLength(); i++ )
aMergeSet.insert( i_rMergeList[i].Name );
@@ -1407,14 +1407,14 @@ const Sequence< PropertyValue >& PrinterController::getUIOptions() const
PropertyValue* PrinterController::getValue( const OUString& i_rProperty )
{
- boost::unordered_map< OUString, size_t, OUStringHash >::const_iterator it =
+ std::unordered_map< OUString, size_t, OUStringHash >::const_iterator it =
mpImplData->maPropertyToIndex.find( i_rProperty );
return it != mpImplData->maPropertyToIndex.end() ? &mpImplData->maUIProperties[it->second] : NULL;
}
const PropertyValue* PrinterController::getValue( const OUString& i_rProperty ) const
{
- boost::unordered_map< OUString, size_t, OUStringHash >::const_iterator it =
+ std::unordered_map< OUString, size_t, OUStringHash >::const_iterator it =
mpImplData->maPropertyToIndex.find( i_rProperty );
return it != mpImplData->maPropertyToIndex.end() ? &mpImplData->maUIProperties[it->second] : NULL;
}
@@ -1430,7 +1430,7 @@ void PrinterController::setValue( const OUString& i_rName, const Any& i_rValue )
void PrinterController::setValue( const PropertyValue& i_rValue )
{
- boost::unordered_map< OUString, size_t, OUStringHash >::const_iterator it =
+ std::unordered_map< OUString, size_t, OUStringHash >::const_iterator it =
mpImplData->maPropertyToIndex.find( i_rValue.Name );
if( it != mpImplData->maPropertyToIndex.end() )
mpImplData->maUIProperties[ it->second ] = i_rValue;
@@ -1510,7 +1510,7 @@ void PrinterController::setUIOptions( const Sequence< PropertyValue >& i_rOption
bool PrinterController::isUIOptionEnabled( const OUString& i_rProperty ) const
{
bool bEnabled = false;
- boost::unordered_map< OUString, size_t, OUStringHash >::const_iterator prop_it =
+ std::unordered_map< OUString, size_t, OUStringHash >::const_iterator prop_it =
mpImplData->maPropertyToIndex.find( i_rProperty );
if( prop_it != mpImplData->maPropertyToIndex.end() )
{
@@ -1745,7 +1745,7 @@ sal_Int32 PrinterController::getIntProperty( const OUString& i_rProperty, sal_In
Any PrinterOptionsHelper::getValue( const OUString& i_rPropertyName ) const
{
Any aRet;
- boost::unordered_map< OUString, Any, OUStringHash >::const_iterator it =
+ std::unordered_map< OUString, Any, OUStringHash >::const_iterator it =
m_aPropertyMap.find( i_rPropertyName );
if( it != m_aPropertyMap.end() )
aRet = it->second;
@@ -1787,7 +1787,7 @@ bool PrinterOptionsHelper::processProperties( const Sequence< PropertyValue >& i
for( sal_Int32 i = 0; i < nElements; i++ )
{
bool bElementChanged = false;
- boost::unordered_map< OUString, Any, OUStringHash >::iterator it =
+ std::unordered_map< OUString, Any, OUStringHash >::iterator it =
m_aPropertyMap.find( pVals[ i ].Name );
if( it != m_aPropertyMap.end() )
{
diff --git a/vcl/source/helper/canvastools.cxx b/vcl/source/helper/canvastools.cxx
index f16a5bcc96a0..54a9ae1f2e36 100644
--- a/vcl/source/helper/canvastools.cxx
+++ b/vcl/source/helper/canvastools.cxx
@@ -57,7 +57,6 @@
#include <canvasbitmap.hxx>
#include <vcl/canvastools.hxx>
-#include <boost/unordered_map.hpp>
using namespace ::com::sun::star;
diff --git a/vcl/source/outdev/font.cxx b/vcl/source/outdev/font.cxx
index 3868a6b35c1e..e20f742b0865 100644
--- a/vcl/source/outdev/font.cxx
+++ b/vcl/source/outdev/font.cxx
@@ -49,9 +49,9 @@
#include "../gdi/pdfwriter_impl.hxx"
+#include <boost/functional/hash.hpp>
#include <cmath>
#include <cstring>
-
#include <memory>
#include <algorithm>
diff --git a/vcl/unx/generic/dtrans/X11_selection.cxx b/vcl/unx/generic/dtrans/X11_selection.cxx
index 53c006776afa..180758c8c166 100644
--- a/vcl/unx/generic/dtrans/X11_selection.cxx
+++ b/vcl/unx/generic/dtrans/X11_selection.cxx
@@ -201,9 +201,9 @@ rtl_TextEncoding x11::getTextPlainEncoding( const OUString& rMimeType )
return aEncoding;
}
-::boost::unordered_map< OUString, SelectionManager*, OUStringHash >& SelectionManager::getInstances()
+std::unordered_map< OUString, SelectionManager*, OUStringHash >& SelectionManager::getInstances()
{
- static ::boost::unordered_map< OUString, SelectionManager*, OUStringHash > aInstances;
+ static std::unordered_map< OUString, SelectionManager*, OUStringHash > aInstances;
return aInstances;
}
@@ -465,7 +465,7 @@ SelectionManager::~SelectionManager()
{
osl::MutexGuard aGuard( *osl::Mutex::getGlobalMutex() );
- ::boost::unordered_map< OUString, SelectionManager*, OUStringHash >::iterator it;
+ std::unordered_map< OUString, SelectionManager*, OUStringHash >::iterator it;
for( it = getInstances().begin(); it != getInstances().end(); ++it )
if( it->second == this )
{
@@ -522,7 +522,7 @@ SelectionManager::~SelectionManager()
SelectionAdaptor* SelectionManager::getAdaptor( Atom selection )
{
- ::boost::unordered_map< Atom, Selection* >::iterator it =
+ std::unordered_map< Atom, Selection* >::iterator it =
m_aSelections.find( selection );
return it != m_aSelections.end() ? it->second->m_pAdaptor : NULL;
}
@@ -681,7 +681,7 @@ SelectionManager& SelectionManager::get( const OUString& rDisplayName )
aDisplayName = OStringToOUString( getenv( "DISPLAY" ), RTL_TEXTENCODING_ISO_8859_1 );
SelectionManager* pInstance = NULL;
- ::boost::unordered_map< OUString, SelectionManager*, OUStringHash >::iterator it = getInstances().find( aDisplayName );
+ std::unordered_map< OUString, SelectionManager*, OUStringHash >::iterator it = getInstances().find( aDisplayName );
if( it != getInstances().end() )
pInstance = it->second;
else pInstance = getInstances()[ aDisplayName ] = new SelectionManager();
@@ -693,7 +693,7 @@ const OUString& SelectionManager::getString( Atom aAtom )
{
osl::MutexGuard aGuard(m_aMutex);
- ::boost::unordered_map< Atom, OUString >::const_iterator it;
+ std::unordered_map< Atom, OUString >::const_iterator it;
if( ( it = m_aAtomToString.find( aAtom ) ) == m_aAtomToString.end() )
{
static OUString aEmpty;
@@ -712,7 +712,7 @@ Atom SelectionManager::getAtom( const OUString& rString )
{
osl::MutexGuard aGuard(m_aMutex);
- ::boost::unordered_map< OUString, Atom, OUStringHash >::const_iterator it;
+ std::unordered_map< OUString, Atom, OUStringHash >::const_iterator it;
if( ( it = m_aStringToAtom.find( rString ) ) == m_aStringToAtom.end() )
{
static Atom nNoDisplayAtoms = 1;
@@ -857,7 +857,7 @@ OUString SelectionManager::convertTypeFromNative( Atom nType, Atom selection, in
bool SelectionManager::getPasteData( Atom selection, Atom type, Sequence< sal_Int8 >& rData )
{
osl::ResettableMutexGuard aGuard(m_aMutex);
- ::boost::unordered_map< Atom, Selection* >::iterator it;
+ std::unordered_map< Atom, Selection* >::iterator it;
bool bSuccess = false;
#if OSL_DEBUG_LEVEL > 1
@@ -994,7 +994,7 @@ bool SelectionManager::getPasteData( Atom selection, const OUString& rType, Sequ
{
bool bSuccess = false;
- ::boost::unordered_map< Atom, Selection* >::iterator it;
+ std::unordered_map< Atom, Selection* >::iterator it;
{
osl::MutexGuard aGuard(m_aMutex);
@@ -1205,7 +1205,7 @@ bool SelectionManager::getPasteData( Atom selection, const OUString& rType, Sequ
bool SelectionManager::getPasteDataTypes( Atom selection, Sequence< DataFlavor >& rTypes )
{
- ::boost::unordered_map< Atom, Selection* >::iterator it;
+ std::unordered_map< Atom, Selection* >::iterator it;
{
osl::MutexGuard aGuard(m_aMutex);
@@ -1408,7 +1408,7 @@ bool SelectionManager::getPasteDataTypes( Atom selection, Sequence< DataFlavor >
PixmapHolder* SelectionManager::getPixmapHolder( Atom selection )
{
- boost::unordered_map< Atom, Selection* >::const_iterator it = m_aSelections.find( selection );
+ std::unordered_map< Atom, Selection* >::const_iterator it = m_aSelections.find( selection );
if( it == m_aSelections.end() )
return NULL;
if( ! it->second->m_pPixmap )
@@ -1510,10 +1510,10 @@ bool SelectionManager::sendData( SelectionAdaptor* pAdaptor,
{
#if OSL_DEBUG_LEVEL > 1
fprintf( stderr, "using INCR protocol\n" );
- boost::unordered_map< ::Window, boost::unordered_map< Atom, IncrementalTransfer > >::const_iterator win_it = m_aIncrementals.find( requestor );
+ std::unordered_map< ::Window, std::unordered_map< Atom, IncrementalTransfer > >::const_iterator win_it = m_aIncrementals.find( requestor );
if( win_it != m_aIncrementals.end() )
{
- boost::unordered_map< Atom, IncrementalTransfer >::const_iterator inc_it = win_it->second.find( property );
+ std::unordered_map< Atom, IncrementalTransfer >::const_iterator inc_it = win_it->second.find( property );
if( inc_it != win_it->second.end() )
{
const IncrementalTransfer& rInc = inc_it->second;
@@ -1781,7 +1781,7 @@ bool SelectionManager::handleReceivePropertyNotify( XPropertyEvent& rNotify )
#endif
bool bHandled = false;
- ::boost::unordered_map< Atom, Selection* >::iterator it =
+ std::unordered_map< Atom, Selection* >::iterator it =
m_aSelections.find( rNotify.atom );
if( it != m_aSelections.end() &&
rNotify.state == PropertyNewValue &&
@@ -1904,13 +1904,13 @@ bool SelectionManager::handleSendPropertyNotify( XPropertyEvent& rNotify )
// feed incrementals
if( rNotify.state == PropertyDelete )
{
- boost::unordered_map< ::Window, boost::unordered_map< Atom, IncrementalTransfer > >::iterator it;
+ std::unordered_map< ::Window, std::unordered_map< Atom, IncrementalTransfer > >::iterator it;
it = m_aIncrementals.find( rNotify.window );
if( it != m_aIncrementals.end() )
{
bHandled = true;
int nCurrentTime = time( NULL );
- boost::unordered_map< Atom, IncrementalTransfer >::iterator inc_it;
+ std::unordered_map< Atom, IncrementalTransfer >::iterator inc_it;
// throw out aborted transfers
std::list< Atom > aTimeouts;
for( inc_it = it->second.begin(); inc_it != it->second.end(); ++inc_it )
@@ -2006,7 +2006,7 @@ bool SelectionManager::handleSelectionNotify( XSelectionEvent& rNotify )
if( rNotify.requestor != m_aWindow && rNotify.requestor != m_aCurrentDropWindow )
fprintf( stderr, "Warning: selection notify for unknown window 0x%lx\n", rNotify.requestor );
#endif
- ::boost::unordered_map< Atom, Selection* >::iterator it =
+ std::unordered_map< Atom, Selection* >::iterator it =
m_aSelections.find( rNotify.selection );
if (
(rNotify.requestor == m_aWindow || rNotify.requestor == m_aCurrentDropWindow) &&
@@ -2087,7 +2087,7 @@ bool SelectionManager::handleDropEvent( XClientMessageEvent& rMessage )
bool bHandled = false;
- ::boost::unordered_map< ::Window, DropTargetEntry >::iterator it =
+ std::unordered_map< ::Window, DropTargetEntry >::iterator it =
m_aDropTargets.find( aTarget );
#if OSL_DEBUG_LEVEL > 1
@@ -2455,7 +2455,7 @@ void SelectionManager::sendDropPosition( bool bForce, Time eventTime )
if( m_bDropSent )
return;
- ::boost::unordered_map< ::Window, DropTargetEntry >::const_iterator it =
+ std::unordered_map< ::Window, DropTargetEntry >::const_iterator it =
m_aDropTargets.find( m_aDropWindow );
if( it != m_aDropTargets.end() )
{
@@ -2516,7 +2516,7 @@ bool SelectionManager::handleDragEvent( XEvent& rMessage )
bool bHandled = false;
// for shortcut
- ::boost::unordered_map< ::Window, DropTargetEntry >::const_iterator it =
+ std::unordered_map< ::Window, DropTargetEntry >::const_iterator it =
m_aDropTargets.find( m_aDropWindow );
#if OSL_DEBUG_LEVEL > 1
switch( rMessage.type )
@@ -3009,7 +3009,7 @@ void SelectionManager::updateDragWindow( int nX, int nY, ::Window aRoot )
dsde.DropAction = nNewProtocolVersion >= 0 ? m_nUserDragAction : DNDConstants::ACTION_COPY;
dsde.UserAction = nNewProtocolVersion >= 0 ? m_nUserDragAction : DNDConstants::ACTION_COPY;
- ::boost::unordered_map< ::Window, DropTargetEntry >::const_iterator it;
+ std::unordered_map< ::Window, DropTargetEntry >::const_iterator it;
if( aNewCurrentWindow != m_aDropWindow )
{
#if OSL_DEBUG_LEVEL > 1
@@ -3162,7 +3162,7 @@ void SelectionManager::startDrag(
int root_x(0), root_y(0), win_x(0), win_y(0);
unsigned int mask(0);
- ::boost::unordered_map< ::Window, DropTargetEntry >::const_iterator it;
+ std::unordered_map< ::Window, DropTargetEntry >::const_iterator it;
it = m_aDropTargets.begin();
while( it != m_aDropTargets.end() )
{
@@ -3558,7 +3558,7 @@ bool SelectionManager::handleXEvent( XEvent& rEvent )
);
#endif
SelectionAdaptor* pAdaptor = getAdaptor( rEvent.xselectionclear.selection );
- boost::unordered_map< Atom, Selection* >::iterator it( m_aSelections.find( rEvent.xselectionclear.selection ) );
+ std::unordered_map< Atom, Selection* >::iterator it( m_aSelections.find( rEvent.xselectionclear.selection ) );
if( it != m_aSelections.end() )
it->second->m_bOwner = false;
aGuard.clear();
@@ -3683,7 +3683,7 @@ void SelectionManager::run( void* pThis )
osl::ClearableMutexGuard aGuard(This->m_aMutex);
std::list< std::pair< SelectionAdaptor*, css::uno::Reference< XInterface > > > aChangeList;
- for( boost::unordered_map< Atom, Selection* >::iterator it = This->m_aSelections.begin(); it != This->m_aSelections.end(); ++it )
+ for( std::unordered_map< Atom, Selection* >::iterator it = This->m_aSelections.begin(); it != This->m_aSelections.end(); ++it )
{
if( it->first != This->m_nXdndSelection && ! it->second->m_bOwner )
{
@@ -3846,7 +3846,7 @@ void SelectionManager::deregisterHandler( Atom selection )
{
osl::MutexGuard aGuard(m_aMutex);
- ::boost::unordered_map< Atom, Selection* >::iterator it =
+ std::unordered_map< Atom, Selection* >::iterator it =
m_aSelections.find( selection );
if( it != m_aSelections.end() )
{
@@ -3873,7 +3873,7 @@ void SelectionManager::registerDropTarget( ::Window aWindow, DropTarget* pTarget
osl::MutexGuard aGuard(m_aMutex);
// sanity check
- ::boost::unordered_map< ::Window, DropTargetEntry >::const_iterator it =
+ std::unordered_map< ::Window, DropTargetEntry >::const_iterator it =
m_aDropTargets.find( aWindow );
if( it != m_aDropTargets.end() )
OSL_FAIL( "attempt to register window as drop target twice" );
@@ -3918,7 +3918,7 @@ void SelectionManager::deregisterDropTarget( ::Window aWindow )
if( aWindow == m_aDragSourceWindow && m_aDragRunning.check() )
{
// abort drag
- boost::unordered_map< ::Window, DropTargetEntry >::const_iterator it =
+ std::unordered_map< ::Window, DropTargetEntry >::const_iterator it =
m_aDropTargets.find( m_aDropWindow );
if( it != m_aDropTargets.end() )
{
diff --git a/vcl/unx/generic/dtrans/X11_selection.hxx b/vcl/unx/generic/dtrans/X11_selection.hxx
index de588345c7fe..c04ae945ed51 100644
--- a/vcl/unx/generic/dtrans/X11_selection.hxx
+++ b/vcl/unx/generic/dtrans/X11_selection.hxx
@@ -34,8 +34,8 @@
#include <osl/conditn.hxx>
-#include <boost/unordered_map.hpp>
#include <list>
+#include <unordered_map>
#include <prex.h>
#include <X11/Xlib.h>
@@ -153,7 +153,7 @@ namespace x11 {
>,
public SelectionAdaptor
{
- static ::boost::unordered_map< OUString, SelectionManager*, OUStringHash >& getInstances();
+ static std::unordered_map< OUString, SelectionManager*, OUStringHash >& getInstances();
// for INCR type selection transfer
// INCR protocol is used if the data cannot
@@ -323,7 +323,7 @@ namespace x11 {
// drag and drop
int m_nCurrentProtocolVersion;
- ::boost::unordered_map< ::Window, DropTargetEntry >
+ std::unordered_map< ::Window, DropTargetEntry >
m_aDropTargets;
// some special atoms that are needed often
@@ -353,16 +353,16 @@ namespace x11 {
Atom m_nXdndActionPrivate;
// caching for atoms
- ::boost::unordered_map< Atom, OUString >
+ std::unordered_map< Atom, OUString >
m_aAtomToString;
- ::boost::unordered_map< OUString, Atom, OUStringHash >
+ std::unordered_map< OUString, Atom, OUStringHash >
m_aStringToAtom;
// the registered selections
- ::boost::unordered_map< Atom, Selection* >
+ std::unordered_map< Atom, Selection* >
m_aSelections;
// IncrementalTransfers in progress
- boost::unordered_map< ::Window, boost::unordered_map< Atom, IncrementalTransfer > >
+ std::unordered_map< ::Window, std::unordered_map< Atom, IncrementalTransfer > >
m_aIncrementals;
// do not use X11 multithreading capabilities
diff --git a/vcl/unx/generic/dtrans/X11_service.cxx b/vcl/unx/generic/dtrans/X11_service.cxx
index 4ec02c123416..360b29d087ad 100644
--- a/vcl/unx/generic/dtrans/X11_service.cxx
+++ b/vcl/unx/generic/dtrans/X11_service.cxx
@@ -73,7 +73,7 @@ css::uno::Reference< XInterface > X11SalInstance::CreateClipboard( const Sequenc
}
Atom nSelection = rManager.getAtom(sel);
- ::boost::unordered_map< Atom, css::uno::Reference< XClipboard > >::iterator it = m_aInstances.find( nSelection );
+ std::unordered_map< Atom, css::uno::Reference< XClipboard > >::iterator it = m_aInstances.find( nSelection );
if( it != m_aInstances.end() )
return it->second;
diff --git a/vcl/unx/generic/gdi/salgdi3.cxx b/vcl/unx/generic/gdi/salgdi3.cxx
index 180992332dda..f0a69ee406e2 100644
--- a/vcl/unx/generic/gdi/salgdi3.cxx
+++ b/vcl/unx/generic/gdi/salgdi3.cxx
@@ -30,7 +30,6 @@
#include <sys/types.h>
#include <basegfx/polygon/b2dpolypolygon.hxx>
-#include <boost/unordered_set.hpp>
#include <i18nlangtag/mslangid.hxx>
#include <osl/file.hxx>
#include <osl/module.hxx>
diff --git a/vcl/unx/generic/printer/cupsmgr.cxx b/vcl/unx/generic/printer/cupsmgr.cxx
index a6ed76d29db0..52a255323c64 100644
--- a/vcl/unx/generic/printer/cupsmgr.cxx
+++ b/vcl/unx/generic/printer/cupsmgr.cxx
@@ -334,7 +334,7 @@ void CUPSManager::initialize()
// behaviour
aPrinter.m_aInfo.m_pParser = NULL;
aPrinter.m_aInfo.m_aContext.setParser( NULL );
- boost::unordered_map< OUString, PPDContext, OUStringHash >::const_iterator c_it = m_aDefaultContexts.find( aPrinterName );
+ std::unordered_map< OUString, PPDContext, OUStringHash >::const_iterator c_it = m_aDefaultContexts.find( aPrinterName );
if( c_it != m_aDefaultContexts.end() )
{
aPrinter.m_aInfo.m_pParser = c_it->second.getParser();
@@ -351,7 +351,7 @@ void CUPSManager::initialize()
// remove everything that is not a CUPS printer and not
// a special purpose printer (PDF, Fax)
std::list< OUString > aRemovePrinters;
- for( boost::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.begin();
+ for( std::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.begin();
it != m_aPrinters.end(); ++it )
{
if( m_aCUPSDestMap.find( it->first ) != m_aCUPSDestMap.end() )
@@ -426,7 +426,7 @@ const PPDParser* CUPSManager::createCUPSParser( const OUString& rPrinter )
{
if (m_nDests && m_pDests)
{
- boost::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
+ std::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
m_aCUPSDestMap.find( aPrinter );
if( dest_it != m_aCUPSDestMap.end() )
{
@@ -503,13 +503,13 @@ const PPDParser* CUPSManager::createCUPSParser( const OUString& rPrinter )
void CUPSManager::setupJobContextData( JobData& rData )
{
- boost::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
+ std::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
m_aCUPSDestMap.find( rData.m_aPrinterName );
if( dest_it == m_aCUPSDestMap.end() )
return PrinterInfoManager::setupJobContextData( rData );
- boost::unordered_map< OUString, Printer, OUStringHash >::iterator p_it =
+ std::unordered_map< OUString, Printer, OUStringHash >::iterator p_it =
m_aPrinters.find( rData.m_aPrinterName );
if( p_it == m_aPrinters.end() ) // huh ?
{
@@ -630,7 +630,7 @@ bool CUPSManager::endSpool( const OUString& rPrintername, const OUString& rJobTi
osl::MutexGuard aGuard( m_aCUPSMutex );
- boost::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
+ std::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
m_aCUPSDestMap.find( rPrintername );
if( dest_it == m_aCUPSDestMap.end() )
{
@@ -638,7 +638,7 @@ bool CUPSManager::endSpool( const OUString& rPrintername, const OUString& rJobTi
return PrinterInfoManager::endSpool( rPrintername, rJobTitle, pFile, rDocumentJobData, bBanner, rFaxNumber );
}
- boost::unordered_map< FILE*, OString, FPtrHash >::const_iterator it = m_aSpoolFiles.find( pFile );
+ std::unordered_map< FILE*, OString, FPtrHash >::const_iterator it = m_aSpoolFiles.find( pFile );
if( it != m_aSpoolFiles.end() )
{
fclose( pFile );
@@ -763,7 +763,7 @@ bool CUPSManager::removePrinter( const OUString& rName, bool bCheck )
bool CUPSManager::setDefaultPrinter( const OUString& rName )
{
bool bSuccess = false;
- boost::unordered_map< OUString, int, OUStringHash >::iterator nit =
+ std::unordered_map< OUString, int, OUStringHash >::iterator nit =
m_aCUPSDestMap.find( rName );
if( nit != m_aCUPSDestMap.end() && m_aCUPSMutex.tryToAcquire() )
{
@@ -787,10 +787,10 @@ bool CUPSManager::writePrinterConfig()
bool bDestModified = false;
rtl_TextEncoding aEncoding = osl_getThreadTextEncoding();
- for( boost::unordered_map< OUString, Printer, OUStringHash >::iterator prt =
+ for( std::unordered_map< OUString, Printer, OUStringHash >::iterator prt =
m_aPrinters.begin(); prt != m_aPrinters.end(); ++prt )
{
- boost::unordered_map< OUString, int, OUStringHash >::iterator nit =
+ std::unordered_map< OUString, int, OUStringHash >::iterator nit =
m_aCUPSDestMap.find( prt->first );
if( nit == m_aCUPSDestMap.end() )
continue;
diff --git a/vcl/unx/generic/printer/ppdparser.cxx b/vcl/unx/generic/printer/ppdparser.cxx
index 7238a44d57f9..ff4cdd685fd7 100644
--- a/vcl/unx/generic/printer/ppdparser.cxx
+++ b/vcl/unx/generic/printer/ppdparser.cxx
@@ -21,7 +21,6 @@
#include <stdio.h>
#include <boost/noncopyable.hpp>
-#include <boost/unordered_map.hpp>
#include <comphelper/string.hxx>
#include "vcl/ppdparser.hxx"
@@ -45,6 +44,8 @@
#include "com/sun/star/lang/Locale.hpp"
+#include <unordered_map>
+
namespace psp
{
class PPDTranslator
@@ -71,8 +72,8 @@ namespace psp
}
};
- typedef boost::unordered_map< com::sun::star::lang::Locale, OUString, LocaleHash, LocaleEqual > translation_map;
- typedef boost::unordered_map< OUString, translation_map, OUStringHash > key_translation_map;
+ typedef std::unordered_map< css::lang::Locale, OUString, LocaleHash, LocaleEqual > translation_map;
+ typedef std::unordered_map< OUString, translation_map, OUStringHash > key_translation_map;
key_translation_map m_aTranslations;
public:
@@ -244,7 +245,7 @@ namespace psp
{
public:
std::list< PPDParser* > aAllParsers;
- boost::unordered_map< OUString, OUString, OUStringHash >* pAllPPDFiles;
+ std::unordered_map< OUString, OUString, OUStringHash >* pAllPPDFiles;
PPDCache()
: pAllPPDFiles(NULL)
{}
@@ -448,7 +449,7 @@ void PPDParser::initPPDFiles(PPDCache &rPPDCache)
if( rPPDCache.pAllPPDFiles )
return;
- rPPDCache.pAllPPDFiles = new boost::unordered_map< OUString, OUString, OUStringHash >();
+ rPPDCache.pAllPPDFiles = new std::unordered_map< OUString, OUString, OUStringHash >();
// check installation directories
std::list< OUString > aPathList;
@@ -483,7 +484,7 @@ OUString PPDParser::getPPDFile( const OUString& rFile )
PPDDecompressStream aStream( aPPD.PathToFileName() );
if( ! aStream.IsOpen() )
{
- boost::unordered_map< OUString, OUString, OUStringHash >::const_iterator it;
+ std::unordered_map< OUString, OUString, OUStringHash >::const_iterator it;
PPDCache &rPPDCache = thePPDCache::get();
bool bRetry = true;
diff --git a/vcl/unx/generic/printer/printerinfomanager.cxx b/vcl/unx/generic/printer/printerinfomanager.cxx
index 5dd8bfe7007c..1272792c6250 100644
--- a/vcl/unx/generic/printer/printerinfomanager.cxx
+++ b/vcl/unx/generic/printer/printerinfomanager.cxx
@@ -47,7 +47,7 @@
// the group of the global defaults
#define GLOBAL_DEFAULTS_GROUP "__Global_Printer_Defaults__"
-#include <boost/unordered_set.hpp>
+#include <unordered_set>
using namespace psp;
using namespace osl;
@@ -463,7 +463,7 @@ void PrinterInfoManager::initialize()
FileBase::getFileURLFromSystemPath( aFile.PathToFileName(), aPrinter.m_aFile );
aPrinter.m_bModified = false;
aPrinter.m_aGroup = aConfig.GetGroupName( nGroup );
- boost::unordered_map< OUString, Printer, OUStringHash >::const_iterator find_it =
+ std::unordered_map< OUString, Printer, OUStringHash >::const_iterator find_it =
m_aPrinters.find( aPrinterName );
if( find_it != m_aPrinters.end() )
{
@@ -537,7 +537,7 @@ void PrinterInfoManager::initialize()
void PrinterInfoManager::listPrinters( ::std::list< OUString >& rList ) const
{
- ::boost::unordered_map< OUString, Printer, OUStringHash >::const_iterator it;
+ std::unordered_map< OUString, Printer, OUStringHash >::const_iterator it;
rList.clear();
for( it = m_aPrinters.begin(); it != m_aPrinters.end(); ++it )
rList.push_back( it->first );
@@ -546,7 +546,7 @@ void PrinterInfoManager::listPrinters( ::std::list< OUString >& rList ) const
const PrinterInfo& PrinterInfoManager::getPrinterInfo( const OUString& rPrinter ) const
{
static PrinterInfo aEmptyInfo;
- ::boost::unordered_map< OUString, Printer, OUStringHash >::const_iterator it = m_aPrinters.find( rPrinter );
+ std::unordered_map< OUString, Printer, OUStringHash >::const_iterator it = m_aPrinters.find( rPrinter );
DBG_ASSERT( it != m_aPrinters.end(), "Do not ask for info about nonexistent printers" );
@@ -555,7 +555,7 @@ const PrinterInfo& PrinterInfoManager::getPrinterInfo( const OUString& rPrinter
void PrinterInfoManager::changePrinterInfo( const OUString& rPrinter, const PrinterInfo& rNewInfo )
{
- ::boost::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.find( rPrinter );
+ std::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.find( rPrinter );
DBG_ASSERT( it != m_aPrinters.end(), "Do not change nonexistant printers" );
@@ -582,9 +582,9 @@ static bool checkWriteability( const OUString& rUniPath )
bool PrinterInfoManager::writePrinterConfig()
{
// find at least one writeable config
- ::boost::unordered_map< OUString, Config*, OUStringHash > files;
- ::boost::unordered_map< OUString, int, OUStringHash > rofiles;
- ::boost::unordered_map< OUString, Config*, OUStringHash >::iterator file_it;
+ std::unordered_map< OUString, Config*, OUStringHash > files;
+ std::unordered_map< OUString, int, OUStringHash > rofiles;
+ std::unordered_map< OUString, Config*, OUStringHash >::iterator file_it;
for( ::std::list< WatchFile >::const_iterator wit = m_aWatchFiles.begin(); wit != m_aWatchFiles.end(); ++wit )
{
@@ -601,7 +601,7 @@ bool PrinterInfoManager::writePrinterConfig()
Config* pGlobal = files.begin()->second;
pGlobal->SetGroup( GLOBAL_DEFAULTS_GROUP );
- ::boost::unordered_map< OUString, Printer, OUStringHash >::iterator it;
+ std::unordered_map< OUString, Printer, OUStringHash >::iterator it;
for( it = m_aPrinters.begin(); it != m_aPrinters.end(); ++it )
{
if( ! it->second.m_bModified )
@@ -772,7 +772,7 @@ bool PrinterInfoManager::removePrinter( const OUString& rPrinterName, bool bChec
{
bool bSuccess = true;
- ::boost::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.find( rPrinterName );
+ std::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.find( rPrinterName );
if( it != m_aPrinters.end() )
{
if( !it->second.m_aFile.isEmpty() )
@@ -823,7 +823,7 @@ bool PrinterInfoManager::setDefaultPrinter( const OUString& rPrinterName )
{
bool bSuccess = false;
- ::boost::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.find( rPrinterName );
+ std::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.find( rPrinterName );
if( it != m_aPrinters.end() )
{
bSuccess = true;
@@ -901,7 +901,7 @@ bool PrinterInfoManager::endSpool( const OUString& /*rPrintername*/, const OUStr
void PrinterInfoManager::setupJobContextData( JobData& rData )
{
- boost::unordered_map< OUString, Printer, OUStringHash >::iterator it =
+ std::unordered_map< OUString, Printer, OUStringHash >::iterator it =
m_aPrinters.find( rData.m_aPrinterName );
if( it != m_aPrinters.end() )
{
@@ -1013,8 +1013,8 @@ static void lpgetSysQueueTokenHandler(
const SystemCommandParameters* )
{
rtl_TextEncoding aEncoding = osl_getThreadTextEncoding();
- boost::unordered_set< OUString, OUStringHash > aUniqueSet;
- boost::unordered_set< OUString, OUStringHash > aOnlySet;
+ std::unordered_set< OUString, OUStringHash > aUniqueSet;
+ std::unordered_set< OUString, OUStringHash > aOnlySet;
aUniqueSet.insert( OUString( "_all" ) );
aUniqueSet.insert( OUString( "_default" ) );
@@ -1110,7 +1110,7 @@ static void standardSysQueueTokenHandler(
const SystemCommandParameters* i_pParms)
{
rtl_TextEncoding aEncoding = osl_getThreadTextEncoding();
- boost::unordered_set< OUString, OUStringHash > aUniqueSet;
+ std::unordered_set< OUString, OUStringHash > aUniqueSet;
OString aForeToken( i_pParms->pForeToken );
OString aAftToken( i_pParms->pAftToken );
/* Normal Unix print queue discovery, also used for Darwin 5 LPR printing
diff --git a/vcl/unx/gtk/gdi/salnativewidgets-gtk.cxx b/vcl/unx/gtk/gdi/salnativewidgets-gtk.cxx
index d0f2bf2ac512..0e142aaa7267 100644
--- a/vcl/unx/gtk/gdi/salnativewidgets-gtk.cxx
+++ b/vcl/unx/gtk/gdi/salnativewidgets-gtk.cxx
@@ -34,7 +34,7 @@
#include <cmath>
#include <vector>
#include <algorithm>
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
#include "vcl/vclenum.hxx"
#include <vcl/settings.hxx>
@@ -175,7 +175,7 @@ struct NWFWidgetData
// Keep a hash table of Widgets->default flags so that we can
// easily and quickly reset each to a default state before using
// them
-static boost::unordered_map<long, guint> gWidgetDefaultFlags;
+static std::unordered_map<long, guint> gWidgetDefaultFlags;
class WidgetDataVector
{
private:
diff --git a/vcl/generic/glyphs/gcach_ftyp.hxx b/vcl/generic/glyphs/gcach_ftyp.hxx
index 21cd6538bcca..beee3328a867 100644
--- a/vcl/generic/glyphs/gcach_ftyp.hxx
+++ b/vcl/generic/glyphs/gcach_ftyp.hxx
@@ -102,8 +102,8 @@ private:
FontCharMapPtr mpFontCharMap;
// cache unicode->glyphid mapping because looking it up is expensive
- // TODO: change to boost::unordered_multimap when a use case requires a m:n mapping
- typedef ::boost::unordered_map<int,int> Int2IntMap;
+ // TODO: change to std::unordered_multimap when a use case requires a m:n mapping
+ typedef std::unordered_map<int,int> Int2IntMap;
mutable Int2IntMap* mpChar2Glyph;
mutable Int2IntMap* mpGlyph2Char;
void InitHashes() const;
@@ -143,7 +143,7 @@ public:
ServerFont* CreateFont( const FontSelectPattern& );
private:
- typedef ::boost::unordered_map<sal_IntPtr,FtFontInfo*> FontList;
+ typedef std::unordered_map<sal_IntPtr,FtFontInfo*> FontList;
FontList maFontList;
sal_IntPtr mnMaxFontId;